========
Plotting
========

The library has a group of conviniance functions for plotting with various backends. 
The goal here is to collect functions for the most popular plotting libraries that work
well out of the box for the majority of cases and provide options for fine tuning.
If you want more control over your plots, you should use these libraries directly.

Plotting with Matplotlib
========================

.. automodule:: sigmaepsilon.mesh.plotting.mpl
    :members:


Plotting with Plotly
====================

.. automodule:: sigmaepsilon.mesh.plotting.plotly
    :members:


Plotting with PyVista
=====================

.. automodule:: sigmaepsilon.mesh.plotting.pvplot
    :members:


Plotting with K3D
=================

.. automodule:: sigmaepsilon.mesh.plotting.k3dplot
    :members: